@@ -7,6 +7,7 @@ import (
 	"github.com/lmorg/murex/config"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/expressions/noglob"
+	"github.com/lmorg/murex/lang/tty"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/shell"
 	"github.com/lmorg/murex/shell/autocomplete"
@@ -255,6 +256,38 @@ func Config(c *config.Config, isInteractive bool) {
 		},
 	})
 
+	c.Define("shell", "start-directory", config.Properties{
+		Description: "If set, this is the default working directory for each new instance of murex. If unset murex will default to the current working directory",
+		Default:     "",
+		DataType:    types.String,
+		Global:      true,
+	})
+
+	c.Define("shell", "tty-buffer-enabled", config.Properties{
+		Description: "EXPERIMENTAL: creates a PTY to buffer STDOUT and STDERR. Mostly works but might cause some edge problems in specific circumstances",
+		Default:     tty.Enabled(),
+		DataType:    types.Boolean,
+		Global:      true,
+		GoFunc: config.GoFuncProperties{
+			Read:  tty.ConfigRead,
+			Write: tty.ConfigWrite,
+		},
+	})
+
+	c.Define("shell", "preview-enabled", config.Properties{
+		Description: "If set, will show file previews in the top right third of the terminal",
+		Default:     tty.Enabled(),
+		DataType:    types.Boolean,
+		Global:      true,
+	})
+
+	c.Define("shell", "preview-images", config.Properties{
+		Description: "If set, file previews will display images as ANSI art rendered graphics rather than text descriptions",
+		Default:     tty.Enabled(),
+		DataType:    types.String,
+		Global:      true,
+	})
+
 	// --- proc ---
 
 	c.Define("proc", "force-tty", config.Properties{
