@@ -5,12 +5,12 @@ package shell
 
 import (
 	"fmt"
-	"os"
 	"os/signal"
 	"syscall"
 
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/state"
+	"github.com/lmorg/murex/lang/tty"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils/humannumbers"
 )
@@ -18,7 +18,7 @@ import (
 // SignalHandler is an internal function to capture and handle OS signals (eg SIGTERM).
 func SignalHandler(interactive bool) {
 	signalRegister(interactive)
-	
+
 	go func() {
 		for {
 			sig := <-signalChan
@@ -37,7 +37,7 @@ func SignalHandler(interactive bool) {
 				sigtstp()
 
 			default:
-				os.Stderr.WriteString("Unhandled signal: " + sig.String())
+				tty.Stderr.WriteString("Unhandled signal: " + sig.String())
 			}
 		}
 	}()
