@@ -6,7 +6,7 @@ package readline
 import (
 	"crypto/md5"
 	"encoding/hex"
-	"io/ioutil"
+	"io"
 	"os"
 	"strconv"
 	"time"
@@ -40,7 +40,7 @@ func readTempFile(name string) ([]byte, error) {
 		return nil, err
 	}
 
-	b, err := ioutil.ReadAll(file)
+	b, err := io.ReadAll(file)
 	if err != nil {
 		return nil, err
 	}
