@@ -13,7 +13,7 @@ func printf(format string, a ...interface{}) {
 	print(s)
 }
 
-//var rxAnsiSgr = regexp.MustCompile("\x1b\\[[:;0-9]+m")
+// var rxAnsiSgr = regexp.MustCompile("\x1b\\[[:;0-9]+m")
 var rxAnsiSgr = regexp.MustCompile(`\x1b\[([0-9]{1,2}(;[0-9]{1,2})*)?[m|K]`)
 
 // Gets the number of runes in a string and
@@ -110,6 +110,11 @@ func lineWrapPos(promptLen, lineLength, termWidth int) (x, y int) {
 		promptLen = 0
 	}
 
+	// avoid divide by zero error
+	if termWidth-promptLen == 0 {
+		return 0, 0
+	}
+
 	y = lineLength / (termWidth - promptLen)
 	if y < 0 {
 		return 0, 0
